==> aegis.2.3.tar.gz: aegis.2.3/aegis/aev.c <==
/*
 *	aegis - project change supervisor
 *	Copyright (C) 1991, 1992, 1993, 1994 Peter Miller.
 *	All rights reserved.
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * MANIFEST: give version information
 */

#include <stdio.h>
#include <ac/stdlib.h>

#include <aev.h>
#include <arglex2.h>
#include <error.h>
#include <help.h>
#include <option.h>
#include <str.h>
#include <trace.h>


static void version_copyright _((void));

static void
version_copyright()
{
	static char *text[] =
	{
		".so cr",
	};
	help(text, SIZEOF(text), (void (*)_((void)))0);
}


static void version_redistribution _((void));

static void
version_redistribution()
{
	static char *text[] =
	{
"GNU GENERAL PUBLIC LICENSE",
".br",
"TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION",
".IP",
"0. This License applies to any program or other work which contains",
"a notice placed by the copyright holder saying it may be distributed",
"under the terms of this General Public License.  The \"Program\", below,",
"refers to any such program or work, and a \"work based on the Program\"",
"means either the Program or any derivative work under copyright law:",
"that is to say, a work containing the Program or a portion of it,",
"either verbatim or with modifications and/or translated into another",
"language.  (Hereinafter, translation is included without limitation in",
"the term \"modification\".)  Each licensee is addressed as \"you\".",
"",
"Activities other than copying, distribution and modification are not",
"covered by this License; they are outside its scope.  The act of",
"running the Program is not restricted, and the output from the Program",
"is covered only if its contents constitute a work based on the",
"Program (independent of having been made by running the Program).",
"Whether that is true depends on what the Program does.",
".IP",
"1. You may copy and distribute verbatim copies of the Program's",
"source code as you receive it, in any medium, provided that you",
"conspicuously and appropriately publish on each copy an appropriate",
"copyright notice and disclaimer of warranty; keep intact all the",
"notices that refer to this License and to the absence of any warranty;",
"and give any other recipients of the Program a copy of this License",
"along with the Program.",
"",
"You may charge a fee for the physical act of transferring a copy, and",
"you may at your option offer warranty protection in exchange for a fee.",
".IP",
"2. You may modify your copy or copies of the Program or any portion",
"of it, thus forming a work based on the Program, and copy and",
"distribute such modifications or work under the terms of Section 1",
"above, provided that you also meet all of these conditions:",
"",
".in +4n",
"a) You must cause the modified files to carry prominent notices",
"stating that you changed the files and the date of any change.",
"",
"b) You must cause any work that you distribute or publish, that in",
"whole or in part contains or is derived from the Program or any",
"part thereof, to be licensed as a whole at no charge to all third",
"parties under the terms of this License.",
"",
"c) If the modified program normally reads commands interactively",
"when run, you must cause it, when started running for such",
"interactive use in the most ordinary way, to print or display an",
"announcement including an appropriate copyright notice and a",
"notice that there is no warranty (or else, saying that you provide",
"a warranty) and that users may redistribute the program under",
"these conditions, and telling the user how to view a copy of this",
"License.  (Exception: if the Program itself is interactive but",
"does not normally print such an announcement, your work based on",
"the Program is not required to print an announcement.)",
".in -4n",
"",
"These requirements apply to the modified work as a whole.  If",
"identifiable sections of that work are not derived from the Program,",
"and can be reasonably considered independent and separate works in",
"themselves, then this License, and its terms, do not apply to those",
"sections when you distribute them as separate works.  But when you",
"distribute the same sections as part of a whole which is a work based",
"on the Program, the distribution of the whole must be on the terms of",
"this License, whose permissions for other licensees extend to the",
"entire whole, and thus to each and every part regardless of who wrote it.",
"",
"Thus, it is not the intent of this section to claim rights or contest",
"your rights to work written entirely by you; rather, the intent is to",
"exercise the right to control the distribution of derivative or",
"collective works based on the Program.",
"",
"In addition, mere aggregation of another work not based on the Program",
"with the Program (or with a work based on the Program) on a volume of",
"a storage or distribution medium does not bring the other work under",
"the scope of this License.",
".IP",
"3. You may copy and distribute the Program (or a work based on it,",
"under Section 2) in object code or executable form under the terms of",
"Sections 1 and 2 above provided that you also do one of the following:",
"",
".in +4n",
"a) Accompany it with the complete corresponding machine-readable",
"source code, which must be distributed under the terms of Sections",
"1 and 2 above on a medium customarily used for software interchange; or,",
"",
"b) Accompany it with a written offer, valid for at least three",
"years, to give any third party, for a charge no more than your",
"cost of physically performing source distribution, a complete",
"machine-readable copy of the corresponding source code, to be",
"distributed under the terms of Sections 1 and 2 above on a medium",
"customarily used for software interchange; or,",
"",
"c) Accompany it with the information you received as to the offer",
"to distribute corresponding source code.  (This alternative is",
"allowed only for noncommercial distribution and only if you",
"received the program in object code or executable form with such",
"an offer, in accord with Subsection b above.)",
".in -4n",
"",
"The source code for a work means the preferred form of the work for",
"making modifications to it.  For an executable work, complete source",
"code means all the source code for all modules it contains, plus any",
"associated interface definition files, plus the scripts used to",
"control compilation and installation of the executable.  However, as a",
"special exception, the source code distributed need not include",
"anything that is normally distributed (in either source or binary",
"form) with the major components (compiler, kernel, and so on) of the",
"operating system on which the executable runs, unless that component",
"itself accompanies the executable.",
"",
"If distribution of executable or object code is made by offering",
"access to copy from a designated place, then offering equivalent",
"access to copy the source code from the same place counts as",
"distribution of the source code, even though third parties are not",
"compelled to copy the source along with the object code.",
".IP",
"4. You may not copy, modify, sublicense, or distribute the Program",
"except as expressly provided under this License.  Any attempt",
"otherwise to copy, modify, sublicense or distribute the Program is",
"void, and will automatically terminate your rights under this License.",
"However, parties who have received copies, or rights, from you under",
"this License will not have their licenses terminated so long as such",
"parties remain in full compliance.",
".IP",
"5. You are not required to accept this License, since you have not",
"signed it.  However, nothing else grants you permission to modify or",
"distribute the Program or its derivative works.  These actions are",
"prohibited by law if you do not accept this License.  Therefore, by",
"modifying or distributing the Program (or any work based on the",
"Program), you indicate your acceptance of this License to do so, and",
"all its terms and conditions for copying, distributing or modifying",
"the Program or works based on it.",
".IP",
"6. Each time you redistribute the Program (or any work based on the",
"Program), the recipient automatically receives a license from the",
"original licensor to copy, distribute or modify the Program subject to",
"these terms and conditions.  You may not impose any further",
"restrictions on the recipients' exercise of the rights granted herein.",
"You are not responsible for enforcing compliance by third parties to",
"this License.",
".IP",
"7. If, as a consequence of a court judgment or allegation of patent",
"infringement or for any other reason (not limited to patent issues),",
"conditions are imposed on you (whether by court order, agreement or",
"otherwise) that contradict the conditions of this License, they do not",
"excuse you from the conditions of this License.  If you cannot",
"distribute so as to satisfy simultaneously your obligations under this",
"License and any other pertinent obligations, then as a consequence you",
"may not distribute the Program at all.  For example, if a patent",
"license would not permit royalty-free redistribution of the Program by",
"all those who receive copies directly or indirectly through you, then",
"the only way you could satisfy both it and this License would be to",
"refrain entirely from distribution of the Program.",
"",
"If any portion of this section is held invalid or unenforceable under",
"any particular circumstance, the balance of the section is intended to",
"apply and the section as a whole is intended to apply in other",
"circumstances.",
"",
"It is not the purpose of this section to induce you to infringe any",
"patents or other property right claims or to contest validity of any",
"such claims; this section has the sole purpose of protecting the",
"integrity of the free software distribution system, which is",
"implemented by public license practices.  Many people have made",
"generous contributions to the wide range of software distributed",
"through that system in reliance on consistent application of that",
"system; it is up to the author/donor to decide if he or she is willing",
"to distribute software through any other system and a licensee cannot",
"impose that choice.",
"",
"This section is intended to make thoroughly clear what is believed to",
"be a consequence of the rest of this License.",
".IP",
"8. If the distribution and/or use of the Program is restricted in",
"certain countries either by patents or by copyrighted interfaces, the",
"original copyright holder who places the Program under this License",
"may add an explicit geographical distribution limitation excluding",
"those countries, so that distribution is permitted only in or among",
"countries not thus excluded.  In such case, this License incorporates",
"the limitation as if written in the body of this License.",
".IP",
"9. The Free Software Foundation may publish revised and/or new versions",
"of the General Public License from time to time.  Such new versions will",
"be similar in spirit to the present version, but may differ in detail to",
"address new problems or concerns.",
"",
"Each version is given a distinguishing version number.  If the Program",
"specifies a version number of this License which applies to it and \"any",
"later version\", you have the option of following the terms and conditions",
"either of that version or of any later version published by the Free",
"Software Foundation.  If the Program does not specify a version number of",
"this License, you may choose any version ever published by the Free Software",
"Foundation.",
".IP",
"10. If you wish to incorporate parts of the Program into other free",
"programs whose distribution conditions are different, write to the author",
"to ask for permission.  For software which is copyrighted by the Free",
"Software Foundation, write to the Free Software Foundation; we sometimes",
"make exceptions for this.  Our decision will be guided by the two goals",
"of preserving the free status of all derivatives of our free software and",
"of promoting the sharing and reuse of software generally.",
	};
	help(text, SIZEOF(text), (void (*)_((void)))0);
}


static void version_warranty _((void));

static void
version_warranty()
{
	static char *text[] =
	{
"NO WARRANTY",
".IP",
"11. BECAUSE THE PROGRAM IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY",
"FOR THE PROGRAM, TO THE EXTENT PERMITTED BY APPLICABLE LAW.  EXCEPT WHEN",
"OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES",
"PROVIDE THE PROGRAM \"AS IS\" WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED",
"OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF",
"MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.  THE ENTIRE RISK AS",
"TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU.  SHOULD THE",
"PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY SERVICING,",
"REPAIR OR CORRECTION.",
".IP",
"12. IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING",
"WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR",
"REDISTRIBUTE THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES,",
"INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING",
"OUT OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED",
"TO LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY",
"YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER",
"PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE",
"POSSIBILITY OF SUCH DAMAGES.",
	};

	help(text, SIZEOF(text), (void (*)_((void)))0);
}


static void version_usage _((void));

static void
version_usage()
{
	char	*progname;

	progname = option_progname_get();
	fprintf(stderr, "usage: %s -VERSion [ <info-name> ]\n", progname);
	fprintf(stderr, "       %s -VERSion -Help\n", progname);
	quit(1);
}


typedef struct table_ty table_ty;
struct table_ty
{
	char	*name;
	void	(*func)_((void));
};


static	table_ty	table[] =
{
	{ "Copyright",		version_copyright,	},
	{ "Redistribution",	version_redistribution,	},
	{ "Warranty",		version_warranty,	},
};


static void version_main _((void));

static void
version_main()
{
	void	(*func)_((void));
	char	*name;

	trace(("version_main()\n{\n"/*}*/));
	name = 0;
	while (arglex_token != arglex_token_eoln)
	{
		switch (arglex_token)
		{
		default:
			generic_argument(version_usage);
			continue;

		case arglex_token_string:
			if (name)
			      fatal("too many version information names given");
			name = arglex_value.alv_string;
			break;
		}
		arglex();
	}

	if (name)
	{
		int		nhit;
		table_ty	*tp;
		string_ty	*s1;
		string_ty	*s2;
		table_ty	*hit[SIZEOF(table)];
		int		j;

		nhit = 0;
		for (tp = table; tp < ENDOF(table); ++tp)
		{
			if (arglex_compare(tp->name, name))
				hit[nhit++] = tp;
		}
		switch (nhit)
		{
		case 0:
			fatal("version information name \"%s\" unknown", name);

		case 1:
			break;

		default:
			s1 = str_from_c(hit[0]->name);
			for (j = 1; j < nhit; ++j)
			{
				s2 = str_format("%S, %s", s1, hit[j]->name);
				str_free(s1);
				s1 = s2;
			}
			fatal
			(
			       "version information name \"%s\" ambiguous (%s)",
				name,
				s1->str_text
			);
		}
		arglex();
		func = hit[0]->func;
	}
	else
		func = version_copyright;

	func();
	trace((/*{*/"}\n"));
}


static void version_help _((void));

static void
version_help()
{
	static char *text[] =
	{
#include <../man1/aev.h>
	};

	help(text, SIZEOF(text), version_usage);
}


void
version()
{
	trace(("version()\n{\n"/*}*/));
	switch (arglex())
	{
	default:
		version_main();
		break;

	case arglex_token_help:
		version_help();
		break;
	}
	trace((/*{*/"}\n"));
}

==> aegis3_3.29.orig.tar.gz: aegis3-3.29.orig/aegis/aev.c <==
/*
 *	aegis - project change supervisor
 *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1999, 2001 Peter Miller;
 *	All rights reserved.
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 *
 * MANIFEST: give version information
 */

#include <ac/stdio.h>

#include <aev.h>
#include <arglex2.h>
#include <error.h>
#include <help.h>
#include <progname.h>
#include <sub.h>
#include <trace.h>
#include <version.h>


static void version_license _((void));

static void
version_license()
{
	help("aelic", (void (*)_((void)))0);
}


static void version_usage _((void));

static void
version_usage()
{
	char	*progname;

	progname = progname_get();
	fprintf(stderr, "usage: %s -VERSion [ <info-name> ]\n", progname);
	fprintf(stderr, "       %s -VERSion -Help\n", progname);
	quit(1);
}


typedef struct table_ty table_ty;
struct table_ty
{
	char	*name;
	void	(*func)_((void));
};


static	table_ty	table[] =
{
	{ "Copyright",	version_copyright,	},
	{ "License",	version_license,	},
};


static void version_main _((void));

static void
version_main()
{
	sub_context_ty	*scp;
	void		(*func)_((void));
	char		*name;

	trace(("version_main()\n{\n"/*}*/));
	arglex();
	name = 0;
	while (arglex_token != arglex_token_eoln)
	{
		switch (arglex_token)
		{
		default:
			generic_argument(version_usage);
			continue;

		case arglex_token_string:
			if (name)
			{
				scp = sub_context_new();
				fatal_intl(scp, i18n("too many info names"));
			}
			name = arglex_value.alv_string;
			break;
		}
		arglex();
	}

	if (name)
	{
		int		nhit;
		table_ty	*tp;
		string_ty	*s1;
		string_ty	*s2;
		table_ty	*hit[SIZEOF(table)];
		int		j;

		nhit = 0;
		for (tp = table; tp < ENDOF(table); ++tp)
		{
			if (arglex_compare(tp->name, name))
				hit[nhit++] = tp;
		}
		switch (nhit)
		{
		case 0:
			scp = sub_context_new();
			sub_var_set_charstar(scp, "Name", name);
			fatal_intl(scp, i18n("no info $name"));
			/* NOTWEACHED */

		case 1:
			break;

		default:
			s1 = str_from_c(hit[0]->name);
			for (j = 1; j < nhit; ++j)
			{
				s2 = str_format("%S, %s", s1, hit[j]->name);
				str_free(s1);
				s1 = s2;
			}
			scp = sub_context_new();
			sub_var_set_charstar(scp, "Name", name);
			sub_var_set_string(scp, "Name_List", s1);
			fatal_intl(scp, i18n("info $name ambig ($name_list)"));
			/* NOTREACHED */
			
		}
		arglex();
		func = hit[0]->func;
	}
	else
		func = version_copyright;

	func();
	trace((/*{*/"}\n"));
}


static void version_help _((void));

static void
version_help()
{
	help("aev", version_usage);
}


void
version()
{
	static arglex_dispatch_ty dispatch[] =
	{
		{ arglex_token_help,		version_help,	},
	};

	trace(("version()\n{\n"));
	arglex_dispatch(dispatch, SIZEOF(dispatch), version_main);
	trace(("}\n"));
}
